<?php
declare(strict_types=1);


namespace App\Controller\Api;


use App\Dto\AddReservationDto;
use App\Entity\Reservation;
use App\Entity\Room;
use App\Repository\RoomRepository;
use App\Service\Reservation\AddReservation;
use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\Routing\Annotation\Route;
use Symfony\Component\Serializer\SerializerInterface;
use Symfony\Component\Validator\Validator\ValidatorInterface;

final class AddReservationController
{
    /**
     * @Route("/api/reservation", name="api_add_reservation", methods={"POST"})
     */
    public function __invoke(
        // stanowczo za dużo zależności. w mojej ocenie 3 to żółte światło 5 czerwone
        Request $request,
        AddReservation $addReservation,
        RoomRepository $roomRepository,
        ValidatorInterface $validator,
        SerializerInterface $serializer
    ): JsonResponse {

        $dto = $serializer->deserialize($request->getContent(), AddReservationDto::class, 'json');
        $errors = $validator->validate($dto);

        if (count($errors) > 0) {
            // zwracane błędy powinny być bardziej czytelne, teraz jest to uproszczone
            $errorsString = (string) $errors;
            return new JsonResponse($errorsString);
        }

        // ten kod mógłby być bardziej elegancki, ale jako przykład jest good enough
        // moglibyśmy np przekazać DTO do serwisu i tam zająć się znalezieniem Room i zapisem
        // w ramach ćwiczeń można przeprowadzić refactoring przenoszący to co poniżej do serwisu

        $room = $roomRepository->find($dto->getRoomId());

        if (!$room instanceof Room) {
            //było by lepiej użyć własnego exception
            throw new \RuntimeException('Room not found');
        }

        $reservation = new Reservation();

        $reservation
            ->setRoom($room)
            ->setDateFrom(new \DateTime($dto->getDateFrom()))
            ->setDateEnd(new \DateTime($dto->getDateFrom()))
        ;

        $addReservation->add($reservation);

        return new JsonResponse(['status' => 'ok']);
    }
}
