<?php
declare(strict_types=1);


namespace App\Dto;

use Symfony\Component\Validator\Constraints as Assert;
use Symfony\Component\Serializer\Annotation\SerializedName;

final class AddReservationDto
{
    /**
     * @Assert\GreaterThan(0)
     * @SerializedName("room_id")
     */
    private int $roomId;

    /**
     * @SerializedName("date_from")
     */
    private string $dateFrom;

    /**
     * @SerializedName("date_to")
     */
    private string $dateTo;

    public function __construct(int $roomId, string $dateFrom, string $dateTo)
    {
        $this->roomId = $roomId;
        $this->dateFrom = $dateFrom;
        $this->dateTo = $dateTo;
    }

    public function getRoomId(): int
    {
        return $this->roomId;
    }

    public function getDateFrom(): string
    {
        return $this->dateFrom;
    }

    public function getDateTo(): string
    {
        return $this->dateTo;
    }

    public static function createFromArray(array $array): self
    {
        return new self(
            $array['roomId'],
            $array['dateFrom'],
            $array['dateTo']
        );
    }
}
