<?php
declare(strict_types=1);


namespace App\Subscriber;

use Psr\Log\LoggerInterface;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;
use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Component\HttpFoundation\RequestStack;
use Symfony\Component\HttpKernel\Event\ExceptionEvent;
use Symfony\Component\HttpKernel\Exception\NotFoundHttpException;
use Symfony\Component\HttpKernel\KernelEvents;

final class ApiExceptionSubscriber implements EventSubscriberInterface
{
    private RequestStack $requestStack;
    private LoggerInterface $logger;

    public function __construct(RequestStack $requestStack, LoggerInterface $logger)
    {
        $this->requestStack = $requestStack;
        $this->logger = $logger;
    }


    public static function getSubscribedEvents()
    {
        return [
//            KernelEvents::EXCEPTION => [
//                ['logException', 50],
//                ['processException', 10],
//            ]

        ];
    }

    public function logException(ExceptionEvent $event)
    {
        $exception = $event->getThrowable();
        $this->logger->alert($exception->getMessage());
    }

    public function processException(ExceptionEvent $event)
    {
        $request = $this->requestStack->getCurrentRequest();

        if ($request && false === strpos($request->getRequestUri(), 'api')) {
            //musimy uważać na użycie w subscribere, bo możemy przerwać działanie
            // "bardziej" niż byśmy chcieli
            return;
        }

        $exception = $event->getThrowable();

        if ($exception instanceof \Throwable) {
            $response = new JsonResponse(
                [
                    'message' => 'Server Error'
                ],
                500
            );

            $event->setResponse($response);
        }

        if ($exception instanceof NotFoundHttpException) {

            $response = new JsonResponse(
                [
                    'message' => 'Entity not found'
                ],
                404
            );

            $event->setResponse($response);
        }

    }
}
